import _plotly_utils.basevalidators


class LonValidator(_plotly_utils.basevalidators.DataArrayValidator):

    def __init__(self, plotly_name='lon', parent_name='scattergeo', **kwargs):
        super(LonValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type='calc',
            role='data',
            **kwargs
        )
