import _plotly_utils.basevalidators


class ContoursValidator(_plotly_utils.basevalidators.CompoundValidator):

    def __init__(
        self, plotly_name='contours', parent_name='surface', **kwargs
    ):
        super(ContoursValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            data_class_str='Contours',
            data_docs="""
            x
                plotly.graph_objs.surface.contours.X instance
                or dict with compatible properties
            y
                plotly.graph_objs.surface.contours.Y instance
                or dict with compatible properties
            z
                plotly.graph_objs.surface.contours.Z instance
                or dict with compatible properties""",
            **kwargs
        )
