from ._xanchor import XanchorValidator
from ._visible import VisibleValidator
from ._suffix import SuffixValidator
from ._prefix import PrefixValidator
from ._offset import OffsetValidator
from ._font import FontValidator
