from plotly.basedatatypes import BaseTraceHierarchyType
import copy


class Project(BaseTraceHierarchyType):

    # x
    # -
    @property
    def x(self):
        """
        Determines whether or not these contour lines are projected on
        the x plane. If `highlight` is set to *true* (the default), the
        projected lines are shown on hover. If `show` is set to *true*,
        the projected lines are shown in permanence.
    
        The 'x' property must be specified as a bool
        (either True, or False)

        Returns
        -------
        bool
        """
        return self['x']

    @x.setter
    def x(self, val):
        self['x'] = val

    # y
    # -
    @property
    def y(self):
        """
        Determines whether or not these contour lines are projected on
        the y plane. If `highlight` is set to *true* (the default), the
        projected lines are shown on hover. If `show` is set to *true*,
        the projected lines are shown in permanence.
    
        The 'y' property must be specified as a bool
        (either True, or False)

        Returns
        -------
        bool
        """
        return self['y']

    @y.setter
    def y(self, val):
        self['y'] = val

    # z
    # -
    @property
    def z(self):
        """
        Determines whether or not these contour lines are projected on
        the z plane. If `highlight` is set to *true* (the default), the
        projected lines are shown on hover. If `show` is set to *true*,
        the projected lines are shown in permanence.
    
        The 'z' property must be specified as a bool
        (either True, or False)

        Returns
        -------
        bool
        """
        return self['z']

    @z.setter
    def z(self, val):
        self['z'] = val

    # property parent name
    # --------------------
    @property
    def _parent_path_str(self):
        return 'surface.contours.y'

    # Self properties description
    # ---------------------------
    @property
    def _prop_descriptions(self):
        return """\
        x
            Determines whether or not these contour lines are
            projected on the x plane. If `highlight` is set to
            *true* (the default), the projected lines are shown on
            hover. If `show` is set to *true*, the projected lines
            are shown in permanence.
        y
            Determines whether or not these contour lines are
            projected on the y plane. If `highlight` is set to
            *true* (the default), the projected lines are shown on
            hover. If `show` is set to *true*, the projected lines
            are shown in permanence.
        z
            Determines whether or not these contour lines are
            projected on the z plane. If `highlight` is set to
            *true* (the default), the projected lines are shown on
            hover. If `show` is set to *true*, the projected lines
            are shown in permanence.
        """

    def __init__(self, arg=None, x=None, y=None, z=None, **kwargs):
        """
        Construct a new Project object
        
        Parameters
        ----------
        arg
            dict of properties compatible with this constructor or
            an instance of
            plotly.graph_objs.surface.contours.y.Project
        x
            Determines whether or not these contour lines are
            projected on the x plane. If `highlight` is set to
            *true* (the default), the projected lines are shown on
            hover. If `show` is set to *true*, the projected lines
            are shown in permanence.
        y
            Determines whether or not these contour lines are
            projected on the y plane. If `highlight` is set to
            *true* (the default), the projected lines are shown on
            hover. If `show` is set to *true*, the projected lines
            are shown in permanence.
        z
            Determines whether or not these contour lines are
            projected on the z plane. If `highlight` is set to
            *true* (the default), the projected lines are shown on
            hover. If `show` is set to *true*, the projected lines
            are shown in permanence.

        Returns
        -------
        Project
        """
        super(Project, self).__init__('project')

        # Validate arg
        # ------------
        if arg is None:
            arg = {}
        elif isinstance(arg, self.__class__):
            arg = arg.to_plotly_json()
        elif isinstance(arg, dict):
            arg = copy.copy(arg)
        else:
            raise ValueError(
                """\
The first argument to the plotly.graph_objs.surface.contours.y.Project 
constructor must be a dict or 
an instance of plotly.graph_objs.surface.contours.y.Project"""
            )

        # Import validators
        # -----------------
        from plotly.validators.surface.contours.y import (project as v_project)

        # Initialize validators
        # ---------------------
        self._validators['x'] = v_project.XValidator()
        self._validators['y'] = v_project.YValidator()
        self._validators['z'] = v_project.ZValidator()

        # Populate data dict with properties
        # ----------------------------------
        _v = arg.pop('x', None)
        self.x = x if x is not None else _v
        _v = arg.pop('y', None)
        self.y = y if y is not None else _v
        _v = arg.pop('z', None)
        self.z = z if z is not None else _v

        # Process unknown kwargs
        # ----------------------
        self._process_kwargs(**dict(arg, **kwargs))
